@@ -40,7 +40,7 @@ ScriptLoggerView::ScriptLoggerView(const TopLevelDataInformation::List& data, QW
     mView->setSelectionBehavior(QAbstractItemView::SelectRows);
     QHeaderView* horizHeader = mView->horizontalHeader();
     horizHeader->setAcceptDrops(false);
-    horizHeader->setResizeMode(QHeaderView::Interactive);
+    horizHeader->setSectionResizeMode(QHeaderView::Interactive);
     horizHeader->setSortIndicatorShown(false);
     horizHeader->setStretchLastSection(true);
     if (!mList.isEmpty())
@@ -48,8 +48,9 @@ ScriptLoggerView::ScriptLoggerView(const TopLevelDataInformation::List& data, QW
         mView->setModel(mList.at(0)->logger());
         mView->resizeRowsToContents();
     }
-    connect(mSelector, SIGNAL(currentIndexChanged(int)), this, SLOT(updateModel(int)));
+    connect(mSelector, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &ScriptLoggerView::updateModel);
     QVBoxLayout* layout = new QVBoxLayout();
+    layout->setMargin(0);
     layout->addWidget(mSelector, 0);
     layout->addWidget(mView, 1);
     setLayout(layout);
