@@ -24,19 +24,21 @@
 #define JOBMANAGER_H
 
 // lib
-#include <kasten/kastencore_export.h>
+#include "kastencore_export.h"
 
 class KJob;
 
-namespace Kasten {
+
+namespace Kasten
+{
 
 class KASTENCORE_EXPORT JobManager
 {
-public:
+  public:
     // temporary, remove quickly
-    static bool executeJob(KJob* job);
+    static bool executeJob( KJob* job );
 
-public:
+  public:
 };
 
 }
