@@ -25,13 +25,13 @@
 
 #include "abstractlinepopup.h"
 
-class KIcon;
+class QIcon;
 class QLabel;
 class QHBoxLayout;
 class QEventLoop;
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 class AbstractLinePopupPrivate
@@ -44,7 +44,7 @@ class AbstractLinePopupPrivate
     void init();
 
     void setPosition( const QPoint& globalPosition );
-    void setIcon( const KIcon& icon );
+    void setIcon( const QIcon& icon );
     void setWidget( QWidget* widget );
 
     void setResult( int result );
